@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef GIRL_H
@@ -70,6 +70,9 @@ void statusbar_send_msg(const char *a, ...);
 
 gchar *copy_to_mem(GnomeVFSURI * uri, GnomeVFSFileSize len);
 
+void appbar_send_msg(const char *a, ...);
+gint girl_archive_new(gchar *title, gchar *file);
+
 /* Fetcher for the channels */
 
 void girl_helper_run(char *url, char *name, GirlStreamType type, GirlHelperType girl);
